# s-tool

Selenium wrapper to make your life easy.

## Features

- [X] Manage multiple webdrivers.
- [X] Click any type of element.
- [X] Extract Page source.
- [X] Select different type of elements.
- [X] Retrive cookies.
- [X] take fullpage and elementwise screenshots.
- [X] display and hide elements.

## TODO

- [ ] Fill information(forms)
- [ ] horizontal and vertical scrolling
- [ ] Handeling alerts and popup
- [ ] Switching windows,tabs,frames.
- [ ] adding universal login functionality with forms
- [ ] handling iframe windows.
- [ ] Writing Parser to extract data from WebDriver.
- [ ] Logging driver activities
